@@ -38,12 +38,11 @@ impl tls_api::TlsConnectorBuilder for TlsConnectorBuilder {
 
     #[cfg(has_alpn)]
     fn set_alpn_protocols(&mut self, protocols: &[&[u8]]) -> Result<()> {
-        self.0.builder_mut().set_alpn_protocols(protocols)
-            .map_err(Error::new)
+        self.0.set_alpn_protocols(protocols).map_err(Error::new)
     }
 
     #[cfg(not(has_alpn))]
-    fn set_alpn_protocols(&mut self, protocols: &[&[u8]]) -> Result<()> {
+    fn set_alpn_protocols(&mut self, _protocols: &[&[u8]]) -> Result<()> {
         Err(Error::new_other("openssl is compiled without alpn"))
     }
 
@@ -52,7 +51,6 @@ impl tls_api::TlsConnectorBuilder for TlsConnectorBuilder {
             .map_err(Error::new)?;
 
         self.0
-            .builder_mut()
             .cert_store_mut()
             .add_cert(cert)
             .map_err(Error::new)?;
@@ -225,12 +223,11 @@ impl tls_api::TlsAcceptorBuilder for TlsAcceptorBuilder {
 
     #[cfg(has_alpn)]
     fn set_alpn_protocols(&mut self, protocols: &[&[u8]]) -> Result<()> {
-        self.0.builder_mut().set_alpn_protocols(protocols)
-            .map_err(Error::new)
+        self.0.set_alpn_protocols(protocols).map_err(Error::new)
     }
 
     #[cfg(not(has_alpn))]
-    fn set_alpn_protocols(&mut self, protocols: &[&[u8]]) -> Result<()> {
+    fn set_alpn_protocols(&mut self, _protocols: &[&[u8]]) -> Result<()> {
         Err(Error::new_other("openssl is compiled without alpn"))
     }
 
